/*
 * Copyright 2017 Rockchip Electronics S.LSI Co. LTD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

#ifndef __TOYBRICK_VENDOR_H__
#define __TOYBRICK_VENDOR_H__

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
	VENDOR_SN_ID = 1,
	VENDOR_WIFI_MAC_ID = 2,
	VENDOR_LAN_MAC_ID = 3,
	VENDOR_BLUETOOTH_ID = 4,

	VENDOR_CUSTOM_ID = 64,
	VENDOR_PRODUCT_ID = 610,
} VendorID;

int vendor_get_data(VendorID id, unsigned char *data, unsigned short data_len);
int vendor_set_data(VendorID id, unsigned char *data, unsigned short data_len);

static inline int vendor_get_sn(unsigned char *data, unsigned short data_len)
{
	return vendor_get_data(VENDOR_SN_ID, data, data_len);
}

int vendor_set_sn(unsigned char *data, unsigned short data_len)
{
	return vendor_set_data(VENDOR_SN_ID, data, data_len);
}

static inline int vendor_get_product(unsigned char *data, unsigned short data_len)
{
	return vendor_get_data(VENDOR_PRODUCT_ID, data, data_len);
}

int vendor_set_product(unsigned char *data, unsigned short data_len)
{
	return vendor_set_data(VENDOR_PRODUCT_ID, data, data_len);
}

#define MAC_LEN		6
static inline void mac_data2str(unsigned char data[MAC_LEN], unsigned char *str)
{
	sprintf(str, "%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x", data[0], data[1], data[2], data[3], data[4], data[5]);
}

static inline void mac_str2data(unsigned char *str, unsigned char data[MAC_LEN])
{
	sscanf((const char *)str, "%2x%2x%2x%2x%2x%2x", 
		(unsigned int *)&data[0],
		(unsigned int *)&data[1],
		(unsigned int *)&data[2],
		(unsigned int *)&data[3],
		(unsigned int *)&data[4],
		(unsigned int *)&data[5]);
}

int vendor_get_macs(unsigned char data[][MAC_LEN], unsigned int count);
int vendor_set_macs(unsigned char data[][MAC_LEN], unsigned int count);

#ifdef __cplusplus
}
#endif

#endif
